from ..utils import random_code


class Algo:
    def __init__(self):
        pass

    def get(self):
        test = random_code()
        return test

    def report(self, test, good, bad):
        pass
